==> arrow-docs-0.8.1-sources.jar: com/example/domain/Success$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Success`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Success`, `kotlin`.`String`> inline get()= arrow.optics.Iso(
  get = { success: `com`.`example`.`domain`.`Success` -> success.content },
  reverseGet = { `com`.`example`.`domain`.`Success`(it) }
)

inline val `com`.`example`.`domain`.`Success`.Companion.content: arrow.optics.Lens<`com`.`example`.`domain`.`Success`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { success: `com`.`example`.`domain`.`Success` -> success.`content` },
  set = { value: `kotlin`.`String` ->
    { success: `com`.`example`.`domain`.`Success` ->
      success.copy(`content` = value)
    }
  }
)



inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content

==> arrow-docs-0.8.2-sources.jar: com/example/domain/Success$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Success`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Success`, `kotlin`.`String`> inline get()= arrow.optics.Iso(
  get = { success: `com`.`example`.`domain`.`Success` -> success.content },
  reverseGet = { `com`.`example`.`domain`.`Success`(it) }
)

inline val `com`.`example`.`domain`.`Success`.Companion.content: arrow.optics.Lens<`com`.`example`.`domain`.`Success`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { success: `com`.`example`.`domain`.`Success` -> success.`content` },
  set = { success: `com`.`example`.`domain`.`Success`, value: `kotlin`.`String` -> success.copy(`content` = value) }
)



inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Success`>.content: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Success`.content
